@@ -4,12 +4,13 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = 'v0.2.1'; # VERSION
+our $VERSION = 'v0.2.2'; # VERSION
 
 use Moose;
 use namespace::autoclean;
 with qw(
 	Business::CyberSource::Request::Role::Common
+	Business::CyberSource::Request::Role::FollowUp
 );
 
 use Business::CyberSource::Response;
@@ -50,33 +51,13 @@ sub submit {
 			})
 			;
 	}
-	elsif ( $r->{decision} eq 'REJECT' ) {
-		$res
-			= Business::CyberSource::Response
-			->with_traits(qw{
-				Business::CyberSource::Response::Role::Reject
-			})
-			->new({
-				decision      => $r->{decision},
-				request_id    => $r->{requestID},
-				reason_code   => "$r->{reasonCode}",
-				request_token => $r->{requestToken},
-			})
-			;
-	}
 	else {
-		croak 'decision defined, but not sane: ' . $r->{decision};
+		$res = $self->_handle_decision( $r );
 	}
 
 	return $res;
 }
 
-has request_id => (
-	required => 1,
-	is       => 'ro',
-	isa      => 'Str',
-);
-
 __PACKAGE__->meta->make_immutable;
 1;
 
@@ -92,7 +73,7 @@ Business::CyberSource::Request::Capture - CyberSource Capture Request Object
 
 =head1 VERSION
 
-version v0.2.1
+version v0.2.2
 
 =head1 SYNOPSIS
 
@@ -177,7 +158,7 @@ Additional documentation: 0: test server. 1: production server
 
 Reader: request_id
 
-Type: Str
+Type: MooseX::Types::Varchar::Varchar[29]
 
 This attribute is required.
 
@@ -209,13 +190,11 @@ Reader: cybs_xsd
 
 Type: MooseX::Types::Path::Class::File
 
-=head2 reference_code
+=head2 client_name
 
-Reader: reference_code
+Reader: client_name
 
-Type: MooseX::Types::Varchar::Varchar[50]
-
-This attribute is required.
+Type: Str
 
 =head2 foreign_currency
 
@@ -223,11 +202,13 @@ Reader: foreign_currency
 
 Type: MooseX::Types::Locale::Currency::CurrencyCode
 
-=head2 client_name
+=head2 reference_code
 
-Reader: client_name
+Reader: reference_code
 
-Type: Str
+Type: MooseX::Types::Varchar::Varchar[50]
+
+This attribute is required.
 
 =head2 client_version
 
