@@ -3,14 +3,15 @@ use 5.008;
 use strict;
 use warnings;
 use Carp;
-our @CARP_NOT = qw( SOAP::Lite );
+use namespace::autoclean;
 
-our $VERSION = 'v0.2.1'; # VERSION
+our $VERSION = 'v0.2.2'; # VERSION
 
 use Moose::Role;
 use MooseX::Types::Moose   qw( HashRef );
 use MooseX::Types::Varchar qw( Varchar );
 use MooseX::Types::URI     qw( Uri     );
+use MooseX::SetOnce;
 
 with qw(
 	Business::CyberSource
@@ -29,19 +30,24 @@ use XML::Compile::Transport::SOAPHTTP;
 sub _build_request {
 	my ( $self, $payload ) = @_;
 
-    my $wss = XML::Compile::SOAP::WSS->new( version => '1.1' );
+	my $wss = XML::Compile::SOAP::WSS->new( version => '1.1' );
 
-    my $wsdl = XML::Compile::WSDL11->new( $self->cybs_wsdl->stringify );
-    $wsdl->importDefinitions( $self->cybs_xsd->stringify );
+	my $wsdl = XML::Compile::WSDL11->new( $self->cybs_wsdl->stringify );
+	$wsdl->importDefinitions( $self->cybs_xsd->stringify );
 
-    my $call = $wsdl->compileClient('runTransaction');
+	my $call = $wsdl->compileClient('runTransaction');
 
-    my $security = $wss->wsseBasicAuth( $self->username, $self->password );
+	my $security = $wss->wsseBasicAuth( $self->username, $self->password );
 
 	my ( $answer, $trace ) = $call->(
 		wsse_Security         => $security,
+		merchantID            => $self->username,
+		merchantReferenceCode => $self->reference_code,
+		clientEnvironment     => $self->client_env,
+		clientLibrary         => $self->client_name,
+		clientLibraryVersion  => $self->client_version,
+		purchaseTotals        => $self->_purchase_info,
 		%{ $payload },
-		%{ $self->_common_req_hash },
 	);
 
 	$self->trace( $trace );
@@ -55,18 +61,29 @@ sub _build_request {
 	return $r;
 }
 
-sub _common_req_hash {
-	my $self = shift;
+sub _handle_decision {
+	my ( $self, $r ) = @_;
 
-	my $i = {
-		merchantID            => $self->username,
-		merchantReferenceCode => $self->reference_code,
-		clientEnvironment     => $self->client_env,
-		clientLibrary         => $self->client_name,
-		clientLibraryVersion  => $self->client_version,
-		purchaseTotals        => $self->_purchase_info,
-	};
-	return $i;
+	my $res;
+	if ( $r->{decision} eq 'REJECT' ) {
+		$res
+			= Business::CyberSource::Response
+			->with_traits(qw{
+				Business::CyberSource::Response::Role::Reject
+			})
+			->new({
+				decision      => $r->{decision},
+				request_id    => $r->{requestID},
+				reason_code   => "$r->{reasonCode}",
+				request_token => $r->{requestToken},
+			})
+			;
+	}
+	else {
+		croak 'decision defined, but not sane: ' . $r->{decision};
+	}
+
+	return $res;
 }
 
 has reference_code => (
@@ -76,8 +93,8 @@ has reference_code => (
 );
 
 has trace => (
-	is  => 'rw',
-	isa => 'XML::Compile::SOAP::Trace',
+	is     => 'rw',
+	isa    => 'XML::Compile::SOAP::Trace',
 );
 
 1;
@@ -93,7 +110,7 @@ Business::CyberSource::Request::Role::Common - Request Role
 
 =head1 VERSION
 
-version v0.2.1
+version v0.2.2
 
 =head1 BUGS
 
